#ifndef IR_SIRCS_H
#define IR_SIRCS_H

#include "ir.h"

// Minimum and maximum length of the gap between bits (nominally 600us)
#define IR_SIRCS_GAP_MIN IR_TIME(500e-6)
#define IR_SIRCS_GAP_MAX IR_TIME(700e-6)

// Minimum and maximum length of the start bit (nominally 2.4ms)
#define IR_SIRCS_START_BIT_MIN IR_TIME(2.3e-3)
#define IR_SIRCS_START_BIT_MAX IR_TIME(2.5e-3)

// Minimum and maximum length of data bits (nominally between 0.6ms and 1.2ms).
#define IR_SIRCS_DATA_BIT_MIN IR_TIME(0.5e-3)
#define IR_SIRCS_DATA_BIT_MAX IR_TIME(1.3e-3)

// Threshold between a 0 and 1 bit length.
#define IR_SIRCS_DATA_BIT_THRESHOLD ((IR_SIRCS_DATA_BIT_MIN+IR_SIRCS_DATA_BIT_MAX)/2)

// Maximum amount of time between received bits before accepting the same command as a repeated press, not a held button.
#define IR_SIRCS_REPEAT_DELAY_MAX IR_TIME(60e-3)

// Defines the receiving stage.
enum ir_sircs_receiving_stage_t {
	IR_SIRCS_RECEIVING_START,
	IR_SIRCS_RECEIVING_COMMAND,
	IR_SIRCS_RECEIVING_ADDRESS,
};

// Call to indicate a signal edge from the IR receiver has been captured.
void ir_sircs_edge_captured(enum ir_edge_direction_t edge, uint16_t delta_time);

// Called when a SIRCS IR code is received.
extern void ir_sircs_code_received(uint8_t address, uint8_t command, uint8_t repeat_count);

#endif